@@ -31,6 +31,7 @@ import tempfile
 import distutils.dist
 import distutils.cmd
 import distutils.errors
+import distutils.fancy_getopt
 try:
     # Standard library of Python 2.7 and later.
     from io import StringIO
@@ -42,9 +43,159 @@ import mock
 import testtools
 import testscenarios
 import docutils
+import docutils.writers
+import docutils.nodes
+import setuptools
+import setuptools.command
 
 import version
 
+version.ensure_class_bases_begin_with(
+        version.__dict__, str('VersionInfoWriter'), docutils.writers.Writer)
+version.ensure_class_bases_begin_with(
+        version.__dict__, str('VersionInfoTranslator'),
+        docutils.nodes.SparseNodeVisitor)
+
+
+def make_test_classes_for_ensure_class_bases_begin_with():
+    """ Make test classes for use with ‘ensure_class_bases_begin_with’.
+
+        :return: Mapping {`name`: `type`} of the custom types created.
+
+        """
+
+    class quux_metaclass(type):
+        def __new__(metaclass, name, bases, namespace):
+            return super(quux_metaclass, metaclass).__new__(
+                    metaclass, name, bases, namespace)
+
+    class Foo(object):
+        __metaclass__ = type
+
+    class Bar(object):
+        pass
+
+    class FooInheritingBar(Bar):
+        __metaclass__ = type
+
+    class FooWithCustomMetaclass(object):
+        __metaclass__ = quux_metaclass
+
+    result = dict(
+            (name, value) for (name, value) in locals().items()
+            if isinstance(value, type))
+
+    return result
+
+class ensure_class_bases_begin_with_TestCase(
+        testscenarios.WithScenarios, testtools.TestCase):
+    """ Test cases for ‘ensure_class_bases_begin_with’ function. """
+
+    test_classes = make_test_classes_for_ensure_class_bases_begin_with()
+
+    scenarios = [
+            ('simple', {
+                'test_class': test_classes['Foo'],
+                'base_class': test_classes['Bar'],
+                }),
+            ('custom metaclass', {
+                'test_class': test_classes['FooWithCustomMetaclass'],
+                'base_class': test_classes['Bar'],
+                'expected_metaclass': test_classes['quux_metaclass'],
+                }),
+            ]
+
+    def setUp(self):
+        """ Set up test fixtures. """
+        super(ensure_class_bases_begin_with_TestCase, self).setUp()
+
+        self.class_name = self.test_class.__name__
+        self.test_module_namespace = {self.class_name: self.test_class}
+
+        if not hasattr(self, 'expected_metaclass'):
+            self.expected_metaclass = type
+
+        patcher_metaclass = mock.patch.object(
+            self.test_class, '__metaclass__')
+        patcher_metaclass.start()
+        self.addCleanup(patcher_metaclass.stop)
+
+        self.fake_new_class = type(object)
+        self.test_class.__metaclass__.return_value = (
+                self.fake_new_class)
+
+    def test_module_namespace_contains_new_class(self):
+        """ Specified module namespace should have new class. """
+        version.ensure_class_bases_begin_with(
+                self.test_module_namespace, self.class_name, self.base_class)
+        self.assertIn(self.fake_new_class, self.test_module_namespace.values())
+
+    def test_calls_metaclass_with_expected_class_name(self):
+        """ Should call the metaclass with the expected class name. """
+        version.ensure_class_bases_begin_with(
+                self.test_module_namespace, self.class_name, self.base_class)
+        expected_class_name = self.class_name
+        self.test_class.__metaclass__.assert_called_with(
+                expected_class_name, mock.ANY, mock.ANY)
+
+    def test_calls_metaclass_with_expected_bases(self):
+        """ Should call the metaclass with the expected bases. """
+        version.ensure_class_bases_begin_with(
+                self.test_module_namespace, self.class_name, self.base_class)
+        expected_bases = tuple(
+                [self.base_class]
+                + list(self.test_class.__bases__))
+        self.test_class.__metaclass__.assert_called_with(
+                mock.ANY, expected_bases, mock.ANY)
+
+    def test_calls_metaclass_with_expected_namespace(self):
+        """ Should call the metaclass with the expected class namespace. """
+        version.ensure_class_bases_begin_with(
+                self.test_module_namespace, self.class_name, self.base_class)
+        expected_namespace = self.test_class.__dict__.copy()
+        del expected_namespace['__dict__']
+        self.test_class.__metaclass__.assert_called_with(
+                mock.ANY, mock.ANY, expected_namespace)
+
+
+class ensure_class_bases_begin_with_AlreadyHasBase_TestCase(
+        testscenarios.WithScenarios, testtools.TestCase):
+    """ Test cases for ‘ensure_class_bases_begin_with’ function.
+
+        These test cases test the conditions where the class's base is
+        already the specified base class.
+
+        """
+
+    test_classes = make_test_classes_for_ensure_class_bases_begin_with()
+
+    scenarios = [
+            ('already Bar subclass', {
+                'test_class': test_classes['FooInheritingBar'],
+                'base_class': test_classes['Bar'],
+                }),
+            ]
+
+    def setUp(self):
+        """ Set up test fixtures. """
+        super(
+                ensure_class_bases_begin_with_AlreadyHasBase_TestCase,
+                self).setUp()
+
+        self.class_name = self.test_class.__name__
+        self.test_module_namespace = {self.class_name: self.test_class}
+
+        patcher_metaclass = mock.patch.object(
+            self.test_class, '__metaclass__')
+        patcher_metaclass.start()
+        self.addCleanup(patcher_metaclass.stop)
+
+    def test_metaclass_not_called(self):
+        """ Should not call metaclass to create a new type. """
+        version.ensure_class_bases_begin_with(
+                self.test_module_namespace, self.class_name, self.base_class)
+        self.assertFalse(self.test_class.__metaclass__.called)
+
 
 class VersionInfoWriter_TestCase(testtools.TestCase):
     """ Test cases for ‘VersionInfoWriter’ class. """
@@ -299,24 +450,6 @@ def make_mock_field_node(field_name, field_body):
 
     return mock_field_node
 
-
-class get_name_for_field_body_TestCase(
-        testscenarios.WithScenarios, testtools.TestCase):
-    """ Test cases for ‘get_name_for_field_body’ function. """
-
-    scenarios = [
-            ('simple', {
-                'test_field_node': make_mock_field_node("Foo", "spam"),
-                'expected_field_name': "Foo",
-                }),
-            ]
-
-    def test_returns_expected_field_name(self):
-        """ Should return expected field name. """
-        field_body_node = self.test_field_node.children[1]
-        result = version.get_name_for_field_body(field_body_node)
-        self.assertEqual(self.expected_field_name, result)
-
 
 class JsonEqual(testtools.matchers.Matcher):
     """ A matcher to compare the value of JSON streams. """
@@ -571,16 +704,13 @@ class changelog_to_version_info_collection_TestCase(
 
     def test_returns_expected_version_info(self):
         """ Should return expected version info mapping. """
-        args = {
-                'infile': StringIO(self.test_input),
-                'writer': version.VersionInfoWriter(),
-                }
+        infile = StringIO(self.test_input)
         if hasattr(self, 'expected_error'):
             self.assertRaises(
                     self.expected_error,
-                    version.changelog_to_version_info_collection, **args)
+                    version.changelog_to_version_info_collection, infile)
         else:
-            result = version.changelog_to_version_info_collection(**args)
+            result = version.changelog_to_version_info_collection(infile)
             self.assertThat(result, JsonEqual(self.expected_version_info))
 
 
@@ -751,46 +881,6 @@ class serialise_version_info_from_mapping_TestCase(
         value = json.loads(result)
         self.assertEqual(self.expected_value, value)
 
-
-@mock.patch.object(version.ChangeLogEntry, 'validate_release_date')
-class validate_distutils_release_date_value_TestCase(
-        testscenarios.WithScenarios, testtools.TestCase):
-    """ Test cases for ‘validate_distutils_release_date_value’ function. """
-
-    scenarios = [
-            ('success', {
-                'validation_effect': (lambda *args, **kwargs: None),
-                'expected_result': None,
-                }),
-            ('failure', {
-                'validation_effect': ValueError("Do not want"),
-                'expected_error': distutils.errors.DistutilsSetupError,
-                }),
-            ]
-
-    def setUp(self):
-        """ Set up test fixtures. """
-        super(validate_distutils_release_date_value_TestCase, self).setUp()
-
-        self.test_args = {
-                'distribution': object(),
-                'attrib': self.getUniqueString(),
-                'value': self.getUniqueString(),
-                }
-
-    def test_returns_expected_result(self, mock_func_validate_release_date):
-        """ Should return expected result. """
-        mock_func_validate_release_date.side_effect = self.validation_effect
-        if hasattr(self, 'expected_error'):
-            self.assertRaises(
-                    self.expected_error,
-                    version.validate_distutils_release_date_value,
-                    **self.test_args)
-        else:
-            result = version.validate_distutils_release_date_value(
-                    **self.test_args)
-            self.assertEqual(self.expected_result, result)
-
 
 DistributionMetadata_defaults = {
         name: None
@@ -824,90 +914,6 @@ def make_fake_distribution(
 
     return distribution
 
-@mock.patch.object(
-        version.ChangeLogEntry, 'make_ordered_dict',
-        new=functools.partial((lambda cls, d: d), version.ChangeLogEntry))
-class generate_version_info_from_distribution_TestCase(
-        testscenarios.WithScenarios, testtools.TestCase):
-    """ Test cases for ‘generate_version_info_from_distribution’ function. """
-
-    scenarios = [
-            ('simple', {
-                'test_distribution': make_fake_distribution(
-                    fields_override={
-                        'release_date': "2001-01-01",
-                        'maintainer': "Foo Bar",
-                        'maintainer_email': "foo.bar@example.org",
-                        },
-                    metadata_fields_override={
-                        'version': "1.0",
-                        },
-                    ),
-                'expected_result': {
-                    'version': "1.0",
-                    'release_date': "2001-01-01",
-                    'maintainer': "Foo Bar <foo.bar@example.org>",
-                    'body': "",
-                    },
-                }),
-            ('no maintainer', {
-                'test_distribution': make_fake_distribution(
-                    fields_override={
-                        'release_date': "2001-01-01",
-                        },
-                    metadata_fields_override={
-                        'version': "1.0",
-                        },
-                    ),
-                'expected_result': {
-                    'version': "1.0",
-                    'release_date': "2001-01-01",
-                    'maintainer': "",
-                    'body': "",
-                    },
-                }),
-            ('no maintainer name', {
-                'test_distribution': make_fake_distribution(
-                    fields_override={
-                        'release_date': "2001-01-01",
-                        'maintainer_email': "foo.bar@example.org",
-                        },
-                    metadata_fields_override={
-                        'version': "1.0",
-                        },
-                    ),
-                'expected_result': {
-                    'version': "1.0",
-                    'release_date': "2001-01-01",
-                    'maintainer': "",
-                    'body': "",
-                    },
-                }),
-            ('no maintainer email', {
-                'test_distribution': make_fake_distribution(
-                    fields_override={
-                        'release_date': "2001-01-01",
-                        'maintainer': "Foo Bar",
-                        },
-                    metadata_fields_override={
-                        'version': "1.0",
-                        },
-                    ),
-                'expected_result': {
-                    'version': "1.0",
-                    'release_date': "2001-01-01",
-                    'maintainer': "",
-                    'body': "",
-                    },
-                }),
-            ]
-
-    def test_returns_expected_result(self):
-        """ Should return expected result. """
-        result = version.generate_version_info_from_distribution(
-                self.test_distribution)
-        self.assertEqual(self.expected_result, result)
-
 
 class get_changelog_path_TestCase(
         testscenarios.WithScenarios, testtools.TestCase):
@@ -963,68 +969,432 @@ class get_changelog_path_TestCase(
         self.assertEqual(self.expected_result, result)
 
 
-@mock.patch.object(version, 'get_changelog_path')
-@mock.patch.object(version, 'generate_version_info_from_changelog')
-@mock.patch.object(version, 'serialise_version_info_from_mapping')
-class generate_egg_info_metadata_TestCase(testtools.TestCase):
-    """ Test cases for ‘generate_egg_info_metadata’ function. """
+class WriteVersionInfoCommand_BaseTestCase(
+        testscenarios.WithScenarios, testtools.TestCase):
+    """ Base class for ‘WriteVersionInfoCommand’ test case classes. """
 
     def setUp(self):
         """ Set up test fixtures. """
-        super(generate_egg_info_metadata_TestCase, self).setUp()
+        super(WriteVersionInfoCommand_BaseTestCase, self).setUp()
+
+        fake_distribution_name = self.getUniqueString()
+
+        self.test_distribution = distutils.dist.Distribution()
+        self.test_distribution.metadata.name = fake_distribution_name
+
+
+class WriteVersionInfoCommand_TestCase(WriteVersionInfoCommand_BaseTestCase):
+    """ Test cases for ‘WriteVersionInfoCommand’ class. """
+
+    def test_subclass_of_distutils_command(self):
+        """ Should be a subclass of ‘distutils.cmd.Command’. """
+        instance = version.WriteVersionInfoCommand(self.test_distribution)
+        self.assertIsInstance(instance, distutils.cmd.Command)
+
+
+class WriteVersionInfoCommand_user_options_TestCase(
+        WriteVersionInfoCommand_BaseTestCase):
+    """ Test cases for ‘WriteVersionInfoCommand.user_options’ attribute. """
+
+    def setUp(self):
+        """ Set up test fixtures. """
+        super(WriteVersionInfoCommand_user_options_TestCase, self).setUp()
+
+        self.test_instance = version.WriteVersionInfoCommand(
+                self.test_distribution)
+        self.commandline_parser = distutils.fancy_getopt.FancyGetopt(
+                self.test_instance.user_options)
+
+    def test_parses_correctly_as_fancy_getopt(self):
+        """ Should parse correctly in ‘FancyGetopt’. """
+        self.assertIsInstance(
+                self.commandline_parser, distutils.fancy_getopt.FancyGetopt)
+
+    def test_includes_base_class_user_options(self):
+        """ Should include base class's user_options. """
+        base_command = setuptools.command.egg_info.egg_info
+        expected_user_options = base_command.user_options
+        self.assertThat(
+                set(expected_user_options),
+                IsSubset(set(self.test_instance.user_options)))
+
+    def test_has_option_changelog_path(self):
+        """ Should have a ‘changelog-path’ option. """
+        expected_option_name = "changelog-path="
+        result = self.commandline_parser.has_option(expected_option_name)
+        self.assertTrue(result)
+
+    def test_has_option_outfile_path(self):
+        """ Should have a ‘outfile-path’ option. """
+        expected_option_name = "outfile-path="
+        result = self.commandline_parser.has_option(expected_option_name)
+        self.assertTrue(result)
+
+
+class WriteVersionInfoCommand_initialize_options_TestCase(
+        WriteVersionInfoCommand_BaseTestCase):
+    """ Test cases for ‘WriteVersionInfoCommand.initialize_options’ method. """
+
+    def setUp(self):
+        """ Set up test fixtures. """
+        super(
+                WriteVersionInfoCommand_initialize_options_TestCase, self
+                ).setUp()
+
+        patcher_func_egg_info_initialize_options = mock.patch.object(
+                setuptools.command.egg_info.egg_info, "initialize_options")
+        patcher_func_egg_info_initialize_options.start()
+        self.addCleanup(patcher_func_egg_info_initialize_options.stop)
+
+    def test_calls_base_class_method(self):
+        """ Should call base class's ‘initialize_options’ method. """
+        instance = version.WriteVersionInfoCommand(self.test_distribution)
+        base_command_class = setuptools.command.egg_info.egg_info
+        base_command_class.initialize_options.assert_called_with()
+
+    def test_sets_changelog_path_to_none(self):
+        """ Should set ‘changelog_path’ attribute to ``None``. """
+        instance = version.WriteVersionInfoCommand(self.test_distribution)
+        self.assertIs(instance.changelog_path, None)
+
+    def test_sets_outfile_path_to_none(self):
+        """ Should set ‘outfile_path’ attribute to ``None``. """
+        instance = version.WriteVersionInfoCommand(self.test_distribution)
+        self.assertIs(instance.outfile_path, None)
+
+
+class WriteVersionInfoCommand_finalize_options_TestCase(
+        WriteVersionInfoCommand_BaseTestCase):
+    """ Test cases for ‘WriteVersionInfoCommand.finalize_options’ method. """
+
+    def setUp(self):
+        """ Set up test fixtures. """
+        super(WriteVersionInfoCommand_finalize_options_TestCase, self).setUp()
+
+        self.test_instance = version.WriteVersionInfoCommand(self.test_distribution)
+
+        patcher_func_egg_info_finalize_options = mock.patch.object(
+                setuptools.command.egg_info.egg_info, "finalize_options")
+        patcher_func_egg_info_finalize_options.start()
+        self.addCleanup(patcher_func_egg_info_finalize_options.stop)
+
+        self.fake_script_dir = self.getUniqueString()
+        self.test_distribution.script_name = os.path.join(
+                self.fake_script_dir, self.getUniqueString())
+
+        self.fake_egg_dir = self.getUniqueString()
+        self.test_instance.egg_info = self.fake_egg_dir
+
+        patcher_func_get_changelog_path = mock.patch.object(
+                version, "get_changelog_path")
+        patcher_func_get_changelog_path.start()
+        self.addCleanup(patcher_func_get_changelog_path.stop)
+
+        self.fake_changelog_path = self.getUniqueString()
+        version.get_changelog_path.return_value = self.fake_changelog_path
+
+    def test_calls_base_class_method(self):
+        """ Should call base class's ‘finalize_options’ method. """
+        base_command_class = setuptools.command.egg_info.egg_info
+        self.test_instance.finalize_options()
+        base_command_class.finalize_options.assert_called_with()
+
+    def test_sets_force_to_none(self):
+        """ Should set ‘force’ attribute to ``None``. """
+        self.test_instance.finalize_options()
+        self.assertIs(self.test_instance.force, None)
+
+    def test_sets_changelog_path_using_get_changelog_path(self):
+        """ Should set ‘changelog_path’ attribute if it was ``None``. """
+        self.test_instance.changelog_path = None
+        self.test_instance.finalize_options()
+        expected_changelog_path = self.fake_changelog_path
+        self.assertEqual(expected_changelog_path, self.test_instance.changelog_path)
+
+    def test_leaves_changelog_path_if_already_set(self):
+        """ Should leave ‘changelog_path’ attribute set. """
+        prior_changelog_path = self.getUniqueString()
+        self.test_instance.changelog_path = prior_changelog_path
+        self.test_instance.finalize_options()
+        expected_changelog_path = prior_changelog_path
+        self.assertEqual(expected_changelog_path, self.test_instance.changelog_path)
+
+    def test_sets_outfile_path_to_default(self):
+        """ Should set ‘outfile_path’ attribute to default value. """
+        fake_version_info_filename = self.getUniqueString()
+        with mock.patch.object(
+                version, "version_info_filename",
+                new=fake_version_info_filename):
+            self.test_instance.finalize_options()
+        expected_outfile_path = os.path.join(
+                self.fake_egg_dir, fake_version_info_filename)
+        self.assertEqual(expected_outfile_path, self.test_instance.outfile_path)
+
+    def test_leaves_outfile_path_if_already_set(self):
+        """ Should leave ‘outfile_path’ attribute set. """
+        prior_outfile_path = self.getUniqueString()
+        self.test_instance.outfile_path = prior_outfile_path
+        self.test_instance.finalize_options()
+        expected_outfile_path = prior_outfile_path
+        self.assertEqual(expected_outfile_path, self.test_instance.outfile_path)
+
+
+class has_changelog_TestCase(
+        testscenarios.WithScenarios, testtools.TestCase):
+    """ Test cases for ‘has_changelog’ function. """
+
+    fake_open_side_effects = {
+            'success': (
+                lambda testcase, *args, **kwargs:
+                    testcase.fake_changelog_file),
+            'file not found': FileNotFoundError(),
+            'permission denied': PermissionError(),
+            }
+
+    fake_os_path_exists_side_effects = {
+            'true': (lambda path: True),
+            'false': (lambda path: False),
+            }
+
+    scenarios = [
+            ('changelog exists', {
+                'os_path_exists_scenario': 'true',
+                'open_scenario': 'success',
+                'expected_result': True,
+                }),
+            ('no changelog path', {
+                'changelog_path': None,
+                'expected_result': False,
+                }),
+            ('changelog not found', {
+                'os_path_exists_scenario': 'false',
+                'open_scenario': 'file not found',
+                'expected_result': False,
+                }),
+            ('changelog not readable', {
+                'os_path_exists_scenario': 'true',
+                'open_scenario': 'permission denied',
+                'expected_result': False,
+                }),
+            ]
+
+    def setUp(self):
+        """ Set up test fixtures. """
+        super(has_changelog_TestCase, self).setUp()
+
+        self.test_distribution = distutils.dist.Distribution()
+        self.test_command = version.EggInfoCommand(
+                self.test_distribution)
+
+        patcher_func_get_changelog_path = mock.patch.object(
+                version, "get_changelog_path")
+        patcher_func_get_changelog_path.start()
+        self.addCleanup(patcher_func_get_changelog_path.stop)
+
+        self.fake_changelog_file_path = self.getUniqueString()
+        if hasattr(self, 'changelog_path'):
+            self.fake_changelog_file_path = self.changelog_path
+        version.get_changelog_path.return_value = self.fake_changelog_file_path
+        self.fake_changelog_file = StringIO()
+
+        def fake_open(filename, mode='rt', buffering=None):
+            if filename == self.fake_changelog_file_path:
+                side_effect = self.fake_open_side_effects[self.open_scenario]
+                if hasattr(side_effect, '__call__'):
+                    result = side_effect(self, filename, mode, buffering)
+                else:
+                    raise side_effect
+            else:
+                result = StringIO()
+            return result
+
+        mock_open = mock.mock_open()
+        mock_open.side_effect = fake_open
+
+        self.func_patcher_builtin_open = mock.patch.object(
+                builtins, "open",
+                new=mock_open)
+
+        def fake_os_path_exists(path):
+            if filename == self.fake_changelog_file_path:
+                side_effect = self.fake_os_path_exists_side_effects[
+                        self.os_path_exists_scenario]
+                if hasattr(side_effect, '__call__'):
+                    result = side_effect(path)
+                else:
+                    raise side_effect
+            else:
+                result = False
+            return result
+
+        func_patcher_os_path_exists = mock.patch.object(
+                os.path, "exists")
+        func_patcher_os_path_exists.start()
+        self.addCleanup(func_patcher_os_path_exists.stop)
+        func_patcher_os_path_exists.side_effect = fake_os_path_exists
+
+    def test_gets_changelog_path_from_distribution(self):
+        """ Should call ‘get_changelog_path’ with distribution. """
+        with self.func_patcher_builtin_open:
+            result = version.has_changelog(self.test_command)
+        version.get_changelog_path.assert_called_with(
+                self.test_distribution)
+
+    def test_returns_expected_result(self):
+        """ Should be a subclass of ‘distutils.cmd.Command’. """
+        with self.func_patcher_builtin_open:
+            result = version.has_changelog(self.test_command)
+        self.assertEqual(self.expected_result, result)
+
+    def test_closes_changelog(self):
+        """ Should close the changelog opened for interrogation. """
+        if getattr(self, 'open_scenario', None) != 'success':
+            self.skipTest("File is not opened, no need to close")
+        with self.func_patcher_builtin_open:
+            result = version.has_changelog(self.test_command)
+        self.assertTrue(self.fake_changelog_file.closed)
+
+
+@mock.patch.object(version, 'generate_version_info_from_changelog')
+@mock.patch.object(version, 'serialise_version_info_from_mapping')
+@mock.patch.object(version.EggInfoCommand, "write_file")
+class WriteVersionInfoCommand_run_TestCase(
+        WriteVersionInfoCommand_BaseTestCase):
+    """ Test cases for ‘WriteVersionInfoCommand.run’ method. """
+
+    def setUp(self):
+        """ Set up test fixtures. """
+        super(WriteVersionInfoCommand_run_TestCase, self).setUp()
+
+        self.test_instance = version.WriteVersionInfoCommand(
+                self.test_distribution)
+
+        self.fake_changelog_path = self.getUniqueString()
+        self.test_instance.changelog_path = self.fake_changelog_path
 
-        self.fake_command = mock.MagicMock(name="Command")
-        self.fake_outfile_name = self.getUniqueString()
         self.fake_outfile_path = self.getUniqueString()
-        self.test_args = {
-                'cmd': self.fake_command,
-                'outfile_name': self.fake_outfile_name,
-                'outfile_path': self.fake_outfile_path,
-                }
+        self.test_instance.outfile_path = self.fake_outfile_path
 
-    def test_gets_changelog_path_from_distribution(
+    def test_returns_none(
             self,
+            mock_func_egg_info_write_file,
             mock_func_serialise_version_info,
-            mock_func_generate_version_info,
-            mock_func_get_changelog_path):
-        """ Should get changelog path from specified distribution. """
-        version.generate_egg_info_metadata(**self.test_args)
-        mock_func_get_changelog_path.assert_called_with(
-                self.fake_command.distribution)
+            mock_func_generate_version_info):
+        """ Should return ``None``. """
+        result = self.test_instance.run()
+        self.assertIs(result, None)
 
     def test_generates_version_info_from_changelog(
             self,
+            mock_func_egg_info_write_file,
             mock_func_serialise_version_info,
-            mock_func_generate_version_info,
-            mock_func_get_changelog_path):
+            mock_func_generate_version_info):
         """ Should generate version info from specified changelog. """
-        version.generate_egg_info_metadata(**self.test_args)
-        expected_changelog_path = mock_func_get_changelog_path.return_value
+        self.test_instance.run()
+        expected_changelog_path = self.test_instance.changelog_path
         mock_func_generate_version_info.assert_called_with(
                 expected_changelog_path)
 
     def test_serialises_version_info_from_mapping(
             self,
+            mock_func_egg_info_write_file,
             mock_func_serialise_version_info,
-            mock_func_generate_version_info,
-            mock_func_get_changelog_path):
+            mock_func_generate_version_info):
         """ Should serialise version info from specified mapping. """
-        version.generate_egg_info_metadata(**self.test_args)
+        self.test_instance.run()
         expected_version_info = mock_func_generate_version_info.return_value
         mock_func_serialise_version_info.assert_called_with(
                 expected_version_info)
 
     def test_writes_file_using_command_context(
             self,
+            mock_func_egg_info_write_file,
             mock_func_serialise_version_info,
-            mock_func_generate_version_info,
-            mock_func_get_changelog_path):
+            mock_func_generate_version_info):
         """ Should write the metadata file using the command context. """
-        version.generate_egg_info_metadata(**self.test_args)
+        self.test_instance.run()
         expected_content = mock_func_serialise_version_info.return_value
-        self.fake_command.write_file.assert_called_with(
+        mock_func_egg_info_write_file.assert_called_with(
                 "version info", self.fake_outfile_path, expected_content)
 
+
+IsSubset = testtools.matchers.MatchesPredicateWithParams(
+        set.issubset, "{0} should be a subset of {1}")
+
+class EggInfoCommand_TestCase(testtools.TestCase):
+    """ Test cases for ‘EggInfoCommand’ class. """
+
+    def setUp(self):
+        """ Set up test fixtures. """
+        super(EggInfoCommand_TestCase, self).setUp()
+
+        self.test_distribution = distutils.dist.Distribution()
+        self.test_instance = version.EggInfoCommand(self.test_distribution)
+
+    def test_subclass_of_setuptools_egg_info(self):
+        """ Should be a subclass of Setuptools ‘egg_info’. """
+        self.assertIsInstance(
+                self.test_instance, setuptools.command.egg_info.egg_info)
+
+    def test_sub_commands_include_base_class_sub_commands(self):
+        """ Should include base class's sub-commands in this sub_commands. """
+        base_command = setuptools.command.egg_info.egg_info
+        expected_sub_commands = base_command.sub_commands
+        self.assertThat(
+                set(expected_sub_commands),
+                IsSubset(set(self.test_instance.sub_commands)))
+
+    def test_sub_commands_includes_write_version_info_command(self):
+        """ Should include sub-command named ‘write_version_info’. """
+        commands_by_name = dict(self.test_instance.sub_commands)
+        expected_predicate = version.has_changelog
+        expected_item = ('write_version_info', expected_predicate)
+        self.assertIn(expected_item, commands_by_name.items())
+
+
+@mock.patch.object(setuptools.command.egg_info.egg_info, "run")
+class EggInfoCommand_run_TestCase(testtools.TestCase):
+    """ Test cases for ‘EggInfoCommand.run’ method. """
+
+    def setUp(self):
+        """ Set up test fixtures. """
+        super(EggInfoCommand_run_TestCase, self).setUp()
+
+        self.test_distribution = distutils.dist.Distribution()
+        self.test_instance = version.EggInfoCommand(self.test_distribution)
+
+        base_command = setuptools.command.egg_info.egg_info
+        patcher_func_egg_info_get_sub_commands = mock.patch.object(
+                base_command, "get_sub_commands")
+        patcher_func_egg_info_get_sub_commands.start()
+        self.addCleanup(patcher_func_egg_info_get_sub_commands.stop)
+
+        patcher_func_egg_info_run_command = mock.patch.object(
+                base_command, "run_command")
+        patcher_func_egg_info_run_command.start()
+        self.addCleanup(patcher_func_egg_info_run_command.stop)
+
+        self.fake_sub_commands = ["spam", "eggs", "beans"]
+        base_command.get_sub_commands.return_value = self.fake_sub_commands
+
+    def test_returns_none(self, mock_func_egg_info_run):
+        """ Should return ``None``. """
+        result = self.test_instance.run()
+        self.assertIs(result, None)
+
+    def test_runs_each_command_in_sub_commands(
+            self, mock_func_egg_info_run):
+        """ Should run each command in ‘self.get_sub_commands()’. """
+        base_command = setuptools.command.egg_info.egg_info
+        self.test_instance.run()
+        expected_calls = [mock.call(name) for name in self.fake_sub_commands]
+        base_command.run_command.assert_has_calls(expected_calls)
+
+    def test_calls_base_class_run(self, mock_func_egg_info_run):
+        """ Should call base class's ‘run’ method. """
+        result = self.test_instance.run()
+        mock_func_egg_info_run.assert_called_with()
+
 
 # Local variables:
 # coding: utf-8
